/*
 * @file tlv320adcx140_page2.h
 *
 * @brief TLV320ADCx140 Descriptor
 *
 * @copyright Copyright (C) 2021 Texas Instruments Incorporated - http://www.ti.com/
 *
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifndef TLV320ADCX140_PAGE2_H_
#define TLV320ADCX140_PAGE2_H_

#include <stdint.h>


//**********************************************************************************
//
// Function prototypes
//
//**********************************************************************************



//**********************************************************************************
//
// Device commands
//
//**********************************************************************************



//**********************************************************************************
//
// Register definitions
//
//**********************************************************************************


/* Register 0x00 (PAGE_CFG) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                       PAGE[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* PAGE_CFG register */
    #define PAGE_CFG_ADDRESS												((uint8_t) 0x00)
    #define PAGE_CFG_DEFAULT												((uint8_t) 0x00)

    /* PAGE field */
    #define PAGE_CFG_PAGE_MASK												((uint8_t) 0xFF)
    #define PAGE_CFG_PAGE_0													((uint8_t) 0x00)    // DEFAULT
    #define PAGE_CFG_PAGE_1													((uint8_t) 0x01)
    #define PAGE_CFG_PAGE_2													((uint8_t) 0x02)
    #define PAGE_CFG_PAGE_3													((uint8_t) 0x03)
    #define PAGE_CFG_PAGE_4													((uint8_t) 0x04)
    #define PAGE_CFG_PAGE_5													((uint8_t) 0x05)
    #define PAGE_CFG_PAGE_6													((uint8_t) 0x06)



/* Register 0x08 (BQ1_N0_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_N0_BYTE1 register */
    #define BQ1_N0_BYTE1_ADDRESS											((uint8_t) 0x08)
    #define BQ1_N0_BYTE1_DEFAULT											((uint8_t) 0x7F)



/* Register 0x09 (BQ1_N0_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_N0_BYTE2 register */
    #define BQ1_N0_BYTE2_ADDRESS											((uint8_t) 0x09)
    #define BQ1_N0_BYTE2_DEFAULT											((uint8_t) 0xFF)



/* Register 0x0A (BQ1_N0_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_N0_BYTE3 register */
    #define BQ1_N0_BYTE3_ADDRESS											((uint8_t) 0x0A)
    #define BQ1_N0_BYTE3_DEFAULT											((uint8_t) 0xFF)



/* Register 0x0B (BQ1_N0_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_N0_BYTE4 register */
    #define BQ1_N0_BYTE4_ADDRESS											((uint8_t) 0x0B)
    #define BQ1_N0_BYTE4_DEFAULT											((uint8_t) 0xFF)



/* Register 0x0C (BQ1_N1_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_N1_BYTE1 register */
    #define BQ1_N1_BYTE1_ADDRESS											((uint8_t) 0x0C)
    #define BQ1_N1_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x0D (BQ1_N1_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_N1_BYTE2 register */
    #define BQ1_N1_BYTE2_ADDRESS											((uint8_t) 0x0D)
    #define BQ1_N1_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x0E (BQ1_N1_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_N1_BYTE3 register */
    #define BQ1_N1_BYTE3_ADDRESS											((uint8_t) 0x0E)
    #define BQ1_N1_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x0F (BQ1_N1_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_N1_BYTE4 register */
    #define BQ1_N1_BYTE4_ADDRESS											((uint8_t) 0x0F)
    #define BQ1_N1_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x10 (BQ1_N2_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_N2_BYTE1 register */
    #define BQ1_N2_BYTE1_ADDRESS											((uint8_t) 0x10)
    #define BQ1_N2_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x11 (BQ1_N2_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_N2_BYTE2 register */
    #define BQ1_N2_BYTE2_ADDRESS											((uint8_t) 0x11)
    #define BQ1_N2_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x12 (BQ1_N2_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_N2_BYTE3 register */
    #define BQ1_N2_BYTE3_ADDRESS											((uint8_t) 0x12)
    #define BQ1_N2_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x13 (BQ1_N2_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_N2_BYTE4 register */
    #define BQ1_N2_BYTE4_ADDRESS											((uint8_t) 0x13)
    #define BQ1_N2_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x14 (BQ1_D1_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_D1_BYTE1 register */
    #define BQ1_D1_BYTE1_ADDRESS											((uint8_t) 0x14)
    #define BQ1_D1_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x15 (BQ1_D1_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_D1_BYTE2 register */
    #define BQ1_D1_BYTE2_ADDRESS											((uint8_t) 0x15)
    #define BQ1_D1_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x16 (BQ1_D1_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_D1_BYTE3 register */
    #define BQ1_D1_BYTE3_ADDRESS											((uint8_t) 0x16)
    #define BQ1_D1_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x17 (BQ1_D1_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_D1_BYTE4 register */
    #define BQ1_D1_BYTE4_ADDRESS											((uint8_t) 0x17)
    #define BQ1_D1_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x18 (BQ1_D2_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_D2_BYTE1 register */
    #define BQ1_D2_BYTE1_ADDRESS											((uint8_t) 0x18)
    #define BQ1_D2_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x19 (BQ1_D2_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_D2_BYTE2 register */
    #define BQ1_D2_BYTE2_ADDRESS											((uint8_t) 0x19)
    #define BQ1_D2_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x1A (BQ1_D2_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_D2_BYTE3 register */
    #define BQ1_D2_BYTE3_ADDRESS											((uint8_t) 0x1A)
    #define BQ1_D2_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x1B (BQ1_D2_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ1_D2_BYTE4 register */
    #define BQ1_D2_BYTE4_ADDRESS											((uint8_t) 0x1B)
    #define BQ1_D2_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x1C (BQ2_N0_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_N0_BYTE1 register */
    #define BQ2_N0_BYTE1_ADDRESS											((uint8_t) 0x1C)
    #define BQ2_N0_BYTE1_DEFAULT											((uint8_t) 0x7F)



/* Register 0x1D (BQ2_N0_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_N0_BYTE2 register */
    #define BQ2_N0_BYTE2_ADDRESS											((uint8_t) 0x1D)
    #define BQ2_N0_BYTE2_DEFAULT											((uint8_t) 0xFF)



/* Register 0x1E (BQ2_N0_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_N0_BYTE3 register */
    #define BQ2_N0_BYTE3_ADDRESS											((uint8_t) 0x1E)
    #define BQ2_N0_BYTE3_DEFAULT											((uint8_t) 0xFF)



/* Register 0x1F (BQ2_N0_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_N0_BYTE4 register */
    #define BQ2_N0_BYTE4_ADDRESS											((uint8_t) 0x1F)
    #define BQ2_N0_BYTE4_DEFAULT											((uint8_t) 0xFF)



/* Register 0x20 (BQ2_N1_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_N1_BYTE1 register */
    #define BQ2_N1_BYTE1_ADDRESS											((uint8_t) 0x20)
    #define BQ2_N1_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x21 (BQ2_N1_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_N1_BYTE2 register */
    #define BQ2_N1_BYTE2_ADDRESS											((uint8_t) 0x21)
    #define BQ2_N1_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x22 (BQ2_N1_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_N1_BYTE3 register */
    #define BQ2_N1_BYTE3_ADDRESS											((uint8_t) 0x22)
    #define BQ2_N1_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x23 (BQ2_N1_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_N1_BYTE4 register */
    #define BQ2_N1_BYTE4_ADDRESS											((uint8_t) 0x23)
    #define BQ2_N1_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x24 (BQ2_N2_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_N2_BYTE1 register */
    #define BQ2_N2_BYTE1_ADDRESS											((uint8_t) 0x24)
    #define BQ2_N2_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x25 (BQ2_N2_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_N2_BYTE2 register */
    #define BQ2_N2_BYTE2_ADDRESS											((uint8_t) 0x25)
    #define BQ2_N2_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x26 (BQ2_N2_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_N2_BYTE3 register */
    #define BQ2_N2_BYTE3_ADDRESS											((uint8_t) 0x26)
    #define BQ2_N2_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x27 (BQ2_N2_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_N2_BYTE4 register */
    #define BQ2_N2_BYTE4_ADDRESS											((uint8_t) 0x27)
    #define BQ2_N2_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x28 (BQ2_D1_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_D1_BYTE1 register */
    #define BQ2_D1_BYTE1_ADDRESS											((uint8_t) 0x28)
    #define BQ2_D1_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x29 (BQ2_D1_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_D1_BYTE2 register */
    #define BQ2_D1_BYTE2_ADDRESS											((uint8_t) 0x29)
    #define BQ2_D1_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x2A (BQ2_D1_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_D1_BYTE3 register */
    #define BQ2_D1_BYTE3_ADDRESS											((uint8_t) 0x2A)
    #define BQ2_D1_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x2B (BQ2_D1_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_D1_BYTE4 register */
    #define BQ2_D1_BYTE4_ADDRESS											((uint8_t) 0x2B)
    #define BQ2_D1_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x2C (BQ2_D2_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_D2_BYTE1 register */
    #define BQ2_D2_BYTE1_ADDRESS											((uint8_t) 0x2C)
    #define BQ2_D2_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x2D (BQ2_D2_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_D2_BYTE2 register */
    #define BQ2_D2_BYTE2_ADDRESS											((uint8_t) 0x2D)
    #define BQ2_D2_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x2E (BQ2_D2_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_D2_BYTE3 register */
    #define BQ2_D2_BYTE3_ADDRESS											((uint8_t) 0x2E)
    #define BQ2_D2_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x2F (BQ2_D2_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ2_D2_BYTE4 register */
    #define BQ2_D2_BYTE4_ADDRESS											((uint8_t) 0x2F)
    #define BQ2_D2_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x30 (BQ3_N0_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_N0_BYTE1 register */
    #define BQ3_N0_BYTE1_ADDRESS											((uint8_t) 0x30)
    #define BQ3_N0_BYTE1_DEFAULT											((uint8_t) 0x7F)



/* Register 0x31 (BQ3_N0_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_N0_BYTE2 register */
    #define BQ3_N0_BYTE2_ADDRESS											((uint8_t) 0x31)
    #define BQ3_N0_BYTE2_DEFAULT											((uint8_t) 0xFF)



/* Register 0x32 (BQ3_N0_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_N0_BYTE3 register */
    #define BQ3_N0_BYTE3_ADDRESS											((uint8_t) 0x32)
    #define BQ3_N0_BYTE3_DEFAULT											((uint8_t) 0xFF)



/* Register 0x33 (BQ3_N0_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_N0_BYTE4 register */
    #define BQ3_N0_BYTE4_ADDRESS											((uint8_t) 0x33)
    #define BQ3_N0_BYTE4_DEFAULT											((uint8_t) 0xFF)



/* Register 0x34 (BQ3_N1_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_N1_BYTE1 register */
    #define BQ3_N1_BYTE1_ADDRESS											((uint8_t) 0x34)
    #define BQ3_N1_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x35 (BQ3_N1_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_N1_BYTE2 register */
    #define BQ3_N1_BYTE2_ADDRESS											((uint8_t) 0x35)
    #define BQ3_N1_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x36 (BQ3_N1_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_N1_BYTE3 register */
    #define BQ3_N1_BYTE3_ADDRESS											((uint8_t) 0x36)
    #define BQ3_N1_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x37 (BQ3_N1_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_N1_BYTE4 register */
    #define BQ3_N1_BYTE4_ADDRESS											((uint8_t) 0x37)
    #define BQ3_N1_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x38 (BQ3_N2_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_N2_BYTE1 register */
    #define BQ3_N2_BYTE1_ADDRESS											((uint8_t) 0x38)
    #define BQ3_N2_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x39 (BQ3_N2_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_N2_BYTE2 register */
    #define BQ3_N2_BYTE2_ADDRESS											((uint8_t) 0x39)
    #define BQ3_N2_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x3A (BQ3_N2_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_N2_BYTE3 register */
    #define BQ3_N2_BYTE3_ADDRESS											((uint8_t) 0x3A)
    #define BQ3_N2_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x3B (BQ3_N2_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_N2_BYTE4 register */
    #define BQ3_N2_BYTE4_ADDRESS											((uint8_t) 0x3B)
    #define BQ3_N2_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x3C (BQ3_D1_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_D1_BYTE1 register */
    #define BQ3_D1_BYTE1_ADDRESS											((uint8_t) 0x3C)
    #define BQ3_D1_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x3D (BQ3_D1_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_D1_BYTE2 register */
    #define BQ3_D1_BYTE2_ADDRESS											((uint8_t) 0x3D)
    #define BQ3_D1_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x3E (BQ3_D1_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_D1_BYTE3 register */
    #define BQ3_D1_BYTE3_ADDRESS											((uint8_t) 0x3E)
    #define BQ3_D1_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x3F (BQ3_D1_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_D1_BYTE4 register */
    #define BQ3_D1_BYTE4_ADDRESS											((uint8_t) 0x3F)
    #define BQ3_D1_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x40 (BQ3_D2_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_D2_BYTE1 register */
    #define BQ3_D2_BYTE1_ADDRESS											((uint8_t) 0x40)
    #define BQ3_D2_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x41 (BQ3_D2_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_D2_BYTE2 register */
    #define BQ3_D2_BYTE2_ADDRESS											((uint8_t) 0x41)
    #define BQ3_D2_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x42 (BQ3_D2_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_D2_BYTE3 register */
    #define BQ3_D2_BYTE3_ADDRESS											((uint8_t) 0x42)
    #define BQ3_D2_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x43 (BQ3_D2_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ3_D2_BYTE4 register */
    #define BQ3_D2_BYTE4_ADDRESS											((uint8_t) 0x43)
    #define BQ3_D2_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x44 (BQ4_N0_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_N0_BYTE1 register */
    #define BQ4_N0_BYTE1_ADDRESS											((uint8_t) 0x44)
    #define BQ4_N0_BYTE1_DEFAULT											((uint8_t) 0x7F)



/* Register 0x45 (BQ4_N0_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_N0_BYTE2 register */
    #define BQ4_N0_BYTE2_ADDRESS											((uint8_t) 0x45)
    #define BQ4_N0_BYTE2_DEFAULT											((uint8_t) 0xFF)



/* Register 0x46 (BQ4_N0_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_N0_BYTE3 register */
    #define BQ4_N0_BYTE3_ADDRESS											((uint8_t) 0x46)
    #define BQ4_N0_BYTE3_DEFAULT											((uint8_t) 0xFF)



/* Register 0x47 (BQ4_N0_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_N0_BYTE4 register */
    #define BQ4_N0_BYTE4_ADDRESS											((uint8_t) 0x47)
    #define BQ4_N0_BYTE4_DEFAULT											((uint8_t) 0xFF)



/* Register 0x48 (BQ4_N1_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_N1_BYTE1 register */
    #define BQ4_N1_BYTE1_ADDRESS											((uint8_t) 0x48)
    #define BQ4_N1_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x49 (BQ4_N1_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_N1_BYTE2 register */
    #define BQ4_N1_BYTE2_ADDRESS											((uint8_t) 0x49)
    #define BQ4_N1_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x4A (BQ4_N1_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_N1_BYTE3 register */
    #define BQ4_N1_BYTE3_ADDRESS											((uint8_t) 0x4A)
    #define BQ4_N1_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x4B (BQ4_N1_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_N1_BYTE4 register */
    #define BQ4_N1_BYTE4_ADDRESS											((uint8_t) 0x4B)
    #define BQ4_N1_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x4C (BQ4_N2_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_N2_BYTE1 register */
    #define BQ4_N2_BYTE1_ADDRESS											((uint8_t) 0x4C)
    #define BQ4_N2_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x4D (BQ4_N2_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_N2_BYTE2 register */
    #define BQ4_N2_BYTE2_ADDRESS											((uint8_t) 0x4D)
    #define BQ4_N2_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x4E (BQ4_N2_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_N2_BYTE3 register */
    #define BQ4_N2_BYTE3_ADDRESS											((uint8_t) 0x4E)
    #define BQ4_N2_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x4F (BQ4_N2_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_N2_BYTE4 register */
    #define BQ4_N2_BYTE4_ADDRESS											((uint8_t) 0x4F)
    #define BQ4_N2_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x50 (BQ4_D1_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_D1_BYTE1 register */
    #define BQ4_D1_BYTE1_ADDRESS											((uint8_t) 0x50)
    #define BQ4_D1_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x51 (BQ4_D1_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_D1_BYTE2 register */
    #define BQ4_D1_BYTE2_ADDRESS											((uint8_t) 0x51)
    #define BQ4_D1_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x52 (BQ4_D1_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_D1_BYTE3 register */
    #define BQ4_D1_BYTE3_ADDRESS											((uint8_t) 0x52)
    #define BQ4_D1_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x53 (BQ4_D1_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_D1_BYTE4 register */
    #define BQ4_D1_BYTE4_ADDRESS											((uint8_t) 0x53)
    #define BQ4_D1_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x54 (BQ4_D2_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_D2_BYTE1 register */
    #define BQ4_D2_BYTE1_ADDRESS											((uint8_t) 0x54)
    #define BQ4_D2_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x55 (BQ4_D2_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_D2_BYTE2 register */
    #define BQ4_D2_BYTE2_ADDRESS											((uint8_t) 0x55)
    #define BQ4_D2_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x56 (BQ4_D2_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_D2_BYTE3 register */
    #define BQ4_D2_BYTE3_ADDRESS											((uint8_t) 0x56)
    #define BQ4_D2_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x57 (BQ4_D2_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ4_D2_BYTE4 register */
    #define BQ4_D2_BYTE4_ADDRESS											((uint8_t) 0x57)
    #define BQ4_D2_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x58 (BQ5_N0_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_N0_BYTE1 register */
    #define BQ5_N0_BYTE1_ADDRESS											((uint8_t) 0x58)
    #define BQ5_N0_BYTE1_DEFAULT											((uint8_t) 0x7F)



/* Register 0x59 (BQ5_N0_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_N0_BYTE2 register */
    #define BQ5_N0_BYTE2_ADDRESS											((uint8_t) 0x59)
    #define BQ5_N0_BYTE2_DEFAULT											((uint8_t) 0xFF)



/* Register 0x5A (BQ5_N0_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_N0_BYTE3 register */
    #define BQ5_N0_BYTE3_ADDRESS											((uint8_t) 0x5A)
    #define BQ5_N0_BYTE3_DEFAULT											((uint8_t) 0xFF)



/* Register 0x5B (BQ5_N0_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_N0_BYTE4 register */
    #define BQ5_N0_BYTE4_ADDRESS											((uint8_t) 0x5B)
    #define BQ5_N0_BYTE4_DEFAULT											((uint8_t) 0xFF)



/* Register 0x5C (BQ5_N1_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_N1_BYTE1 register */
    #define BQ5_N1_BYTE1_ADDRESS											((uint8_t) 0x5C)
    #define BQ5_N1_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x5D (BQ5_N1_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_N1_BYTE2 register */
    #define BQ5_N1_BYTE2_ADDRESS											((uint8_t) 0x5D)
    #define BQ5_N1_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x5E (BQ5_N1_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_N1_BYTE3 register */
    #define BQ5_N1_BYTE3_ADDRESS											((uint8_t) 0x5E)
    #define BQ5_N1_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x5F (BQ5_N1_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_N1_BYTE4 register */
    #define BQ5_N1_BYTE4_ADDRESS											((uint8_t) 0x5F)
    #define BQ5_N1_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x60 (BQ5_N2_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_N2_BYTE1 register */
    #define BQ5_N2_BYTE1_ADDRESS											((uint8_t) 0x60)
    #define BQ5_N2_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x61 (BQ5_N2_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_N2_BYTE2 register */
    #define BQ5_N2_BYTE2_ADDRESS											((uint8_t) 0x61)
    #define BQ5_N2_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x61 (BQ5_N2_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_N2_BYTE3 register */
    #define BQ5_N2_BYTE3_ADDRESS											((uint8_t) 0x61)
    #define BQ5_N2_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x63 (BQ5_N2_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_N2_BYTE4 register */
    #define BQ5_N2_BYTE4_ADDRESS											((uint8_t) 0x63)
    #define BQ5_N2_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x64 (BQ5_D1_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_D1_BYTE1 register */
    #define BQ5_D1_BYTE1_ADDRESS											((uint8_t) 0x64)
    #define BQ5_D1_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x65 (BQ5_D1_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_D1_BYTE2 register */
    #define BQ5_D1_BYTE2_ADDRESS											((uint8_t) 0x65)
    #define BQ5_D1_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x66 (BQ5_D1_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_D1_BYTE3 register */
    #define BQ5_D1_BYTE3_ADDRESS											((uint8_t) 0x66)
    #define BQ5_D1_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x67 (BQ5_D1_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_D1_BYTE4 register */
    #define BQ5_D1_BYTE4_ADDRESS											((uint8_t) 0x67)
    #define BQ5_D1_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x68 (BQ5_D2_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_D2_BYTE1 register */
    #define BQ5_D2_BYTE1_ADDRESS											((uint8_t) 0x68)
    #define BQ5_D2_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x69 (BQ5_D2_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_D2_BYTE2 register */
    #define BQ5_D2_BYTE2_ADDRESS											((uint8_t) 0x69)
    #define BQ5_D2_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x6A (BQ5_D2_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_D2_BYTE3 register */
    #define BQ5_D2_BYTE3_ADDRESS											((uint8_t) 0x6A)
    #define BQ5_D2_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x6B (BQ5_D2_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ5_D2_BYTE4 register */
    #define BQ5_D2_BYTE4_ADDRESS											((uint8_t) 0x6B)
    #define BQ5_D2_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x6C (BQ6_N0_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_N0_BYTE1 register */
    #define BQ6_N0_BYTE1_ADDRESS											((uint8_t) 0x6C)
    #define BQ6_N0_BYTE1_DEFAULT											((uint8_t) 0x7F)



/* Register 0x6D (BQ6_N0_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_N0_BYTE2 register */
    #define BQ6_N0_BYTE2_ADDRESS											((uint8_t) 0x6D)
    #define BQ6_N0_BYTE2_DEFAULT											((uint8_t) 0xFF)



/* Register 0x6E (BQ6_N0_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_N0_BYTE3 register */
    #define BQ6_N0_BYTE3_ADDRESS											((uint8_t) 0x6E)
    #define BQ6_N0_BYTE3_DEFAULT											((uint8_t) 0xFF)



/* Register 0x6F (BQ6_N0_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_N0_BYTE4 register */
    #define BQ6_N0_BYTE4_ADDRESS											((uint8_t) 0x6F)
    #define BQ6_N0_BYTE4_DEFAULT											((uint8_t) 0xFF)



/* Register 0x70 (BQ6_N1_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_N1_BYTE1 register */
    #define BQ6_N1_BYTE1_ADDRESS											((uint8_t) 0x70)
    #define BQ6_N1_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x71 (BQ6_N1_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_N1_BYTE2 register */
    #define BQ6_N1_BYTE2_ADDRESS											((uint8_t) 0x71)
    #define BQ6_N1_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x72 (BQ6_N1_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_N1_BYTE3 register */
    #define BQ6_N1_BYTE3_ADDRESS											((uint8_t) 0x72)
    #define BQ6_N1_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x73 (BQ6_N1_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_N1_BYTE4 register */
    #define BQ6_N1_BYTE4_ADDRESS											((uint8_t) 0x73)
    #define BQ6_N1_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x74 (BQ6_N2_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_N2_BYTE1 register */
    #define BQ6_N2_BYTE1_ADDRESS											((uint8_t) 0x74)
    #define BQ6_N2_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x75 (BQ6_N2_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_N2_BYTE2 register */
    #define BQ6_N2_BYTE2_ADDRESS											((uint8_t) 0x75)
    #define BQ6_N2_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x76 (BQ6_N2_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_N2_BYTE3 register */
    #define BQ6_N2_BYTE3_ADDRESS											((uint8_t) 0x76)
    #define BQ6_N2_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x77 (BQ6_N2_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_N2_BYTE4 register */
    #define BQ6_N2_BYTE4_ADDRESS											((uint8_t) 0x77)
    #define BQ6_N2_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x78 (BQ6_D1_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_D1_BYTE1 register */
    #define BQ6_D1_BYTE1_ADDRESS											((uint8_t) 0x78)
    #define BQ6_D1_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x79 (BQ6_D1_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_D1_BYTE2 register */
    #define BQ6_D1_BYTE2_ADDRESS											((uint8_t) 0x79)
    #define BQ6_D1_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x7A (BQ6_D1_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_D1_BYTE3 register */
    #define BQ6_D1_BYTE3_ADDRESS											((uint8_t) 0x7A)
    #define BQ6_D1_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x7B (BQ6_D1_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_D1_BYTE4 register */
    #define BQ6_D1_BYTE4_ADDRESS											((uint8_t) 0x7B)
    #define BQ6_D1_BYTE4_DEFAULT											((uint8_t) 0x00)



/* Register 0x7C (BQ6_D2_BYTE1) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        MSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_D2_BYTE1 register */
    #define BQ6_D2_BYTE1_ADDRESS											((uint8_t) 0x7C)
    #define BQ6_D2_BYTE1_DEFAULT											((uint8_t) 0x00)



/* Register 0x7D (BQ6_D2_BYTE2) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B2[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_D2_BYTE2 register */
    #define BQ6_D2_BYTE2_ADDRESS											((uint8_t) 0x7D)
    #define BQ6_D2_BYTE2_DEFAULT											((uint8_t) 0x00)



/* Register 0x7E (BQ6_D2_BYTE3) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        B1[7:0]                                        |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_D2_BYTE3 register */
    #define BQ6_D2_BYTE3_ADDRESS											((uint8_t) 0x7E)
    #define BQ6_D2_BYTE3_DEFAULT											((uint8_t) 0x00)



/* Register 0x7F (BQ6_D2_BYTE4) definition
 * |---------------------------------------------------------------------------------------|
 * |   Bit 7  |   Bit 6  |   Bit 5  |   Bit 4  |   Bit 3  |   Bit 2  |   Bit 1  |   Bit 0  |
 * |---------------------------------------------------------------------------------------|
 * |                                        LSB[7:0]                                       |
 * |---------------------------------------------------------------------------------------|
 */

    /* BQ6_D2_BYTE4 register */
    #define BQ6_D2_BYTE4_ADDRESS											((uint8_t) 0x7F)
    #define BQ6_D2_BYTE4_DEFAULT											((uint8_t) 0x00)



#endif /* TLV320ADCX140_PAGE2_H_ */
